#!/usr/bin/env python3

import os
import sys

from . import forms
from . import consts
from . import youtube as yt

import pyforms_lite


def main():
    try:
        if os.path.isfile(consts.youtube_file) or not len(os.listdir(consts.smash_folder)):
            consts.youtube = yt.get_youtube_service()
        elif len(os.listdir(consts.smash_folder)):
            pyforms_lite.start_app(forms.YouTubeSelector, geometry=(200, 200, 1, 1))
            consts.youtube = yt.get_youtube_service()
    except Exception as e:
        print(e)
        print("There was an issue with getting Google Credentials")
        sys.exit(1)
    try:
        if os.path.isfile(consts.partner_file):
            consts.partner = yt.get_partner_service()
    except Exception as e:
        print(e)
    try:
        pyforms_lite.start_app(forms.MeleeUploader, geometry=(200, 200, 1, 1))
    except Exception as e:
        print("Error:", e)
        sys.exit(1)

def s64():
    consts.game = "64"
    main()

def melee():
    main()

def ult():
    consts.game = "ult"
    main()

def rivals():
    consts.game = "rivals"
    main()

def splatoon():
    consts.game = "splatoon"
    main()


if __name__ == "__main__":
    main()



#!/usr/bin/env python3

from . import consts

from pyforms_lite import BaseWidget
from pyforms_lite.controls import ControlButton, ControlList


class OptionsViewer(BaseWidget):
    def __init__(self, pos, options):
        super(OptionsViewer, self).__init__(f"Options #{pos}")
        self.pos = pos
        self.options = options
        self._oview = ControlList()
        self._oview.horizontal_headers = ["Key", "Value"]
        self.formset = ["_oview"]
        if pos or consts.stop_thread:
            self._deletebutton = ControlButton("Remove from Queue")
            self._deletebutton.value = self.__delete_job
            self.formset = ["_oview", "=", "_deletebutton"]
        self.__update_o_view()
        self._oview.data_changed_event = self.__update_data
    
    def __update_data(self, row, col, item):
        if col == 1:
            var_name = self._oview.get_value(0, row)
            if "char" in var_name:
                item = item.split("/")
            self.options.__dict__[var_name] = item
            self.parent._MeleeUploader__update_qview(self.pos, self.options)
            print(f"{var_name} in queue item {self.pos} was updated to {item}")

    def __delete_job(self):
        self._oview.readonly = True
        self.close()
        self.parent._MeleeUploader__delete_from_queue_view(self.pos)

    def __update_o_view(self):
        self._oview.clear()
        for key in self.options.__dict__.keys():
            value = self.options.__dict__[key]
            if "char" in key:
                value = "/".join(value)
            self._oview += (key, value)
        self._oview.resize_rows_contents()


class HistoryViewer(BaseWidget):
    def __init__(self, history):
        super(HistoryViewer, self).__init__("History")
        self._history = history
        self._qview = ControlList(select_entire_row=True)
        self._qview.cell_double_clicked_event = self.__load_row
        self._qview.readonly = True
        self._qview.horizontal_headers = ["Player 1", "Player 2", "Match Type"]

        for options in self._history:
            self._qview += (options[3], options[4], " ".join((options[11], options[2], options[10])))

    def __load_row(self, row, c):
        self.parent._MeleeUploader__load_form(self._history[row])



import sys

from .main import main, ult, s64, rivals, splatoon

print(sys.argv)

if any(x in sys.argv for x in ("ult", "ultimate", "smash5", "sm5sh")):
    ult()
elif any(x in sys.argv for x in ("s64", "64", "ssb")):
    s64()
elif any(x in sys.argv for x in ("rivals", "roa", "rivalsofaether")):
    rivals()
elif any(x in sys.argv for x in ("splatoon", "splat")):
    splatoon()
else:
    main()
